package com.zhyc.module.produce.manage_sheep.service;

import java.util.List;
import com.zhyc.module.produce.manage_sheep.domain.ScChangeComment;

/**
 * 改备注Service接口
 * 
 * @author ruoyi
 * @date 2025-07-24
 */
public interface IScChangeCommentService 
{
    /**
     * 查询改备注
     * 
     * @param id 改备注主键
     * @return 改备注
     */
    public ScChangeComment selectScChangeCommentById(Long id);

    /**
     * 查询改备注列表
     * 
     * @param scChangeComment 改备注
     * @return 改备注集合
     */
    public List<ScChangeComment> selectScChangeCommentList(ScChangeComment scChangeComment);

    /**
     * 新增改备注
     * 
     * @param scChangeComment 改备注
     * @return 结果
     */
    public int insertScChangeComment(ScChangeComment scChangeComment);

    /**
     * 修改改备注
     * 
     * @param scChangeComment 改备注
     * @return 结果
     */
    public int updateScChangeComment(ScChangeComment scChangeComment);

    /**
     * 批量删除改备注
     * 
     * @param ids 需要删除的改备注主键集合
     * @return 结果
     */
    public int deleteScChangeCommentByIds(Long[] ids);

    /**
     * 删除改备注信息
     * 
     * @param id 改备注主键
     * @return 结果
     */
    public int deleteScChangeCommentById(Long id);

    /**
     * 远程模糊搜索耳号（下拉用）
     */
    List<String> searchEarNumbers(String query);
}
